@@ -2,7 +2,10 @@ package ansi
 
 import (
 	"fmt"
+	"slices"
 	"strings"
+
+	"github.com/jandedobbeleer/oh-my-posh/src/shell"
 )
 
 type iTermFeature string
@@ -15,11 +18,27 @@ const (
 
 type ITermFeatures []iTermFeature
 
-func (w *Writer) RenderItermFeatures(features ITermFeatures, pwd, user, host string) string {
+func (f ITermFeatures) Contains(feature iTermFeature) bool {
+	for _, item := range f {
+		if item == feature {
+			return true
+		}
+	}
+
+	return false
+}
+
+func (w *Writer) RenderItermFeatures(features ITermFeatures, sh, pwd, user, host string) string {
+	supportedShells := []string{shell.BASH, shell.ZSH}
+
 	var result strings.Builder
 	for _, feature := range features {
 		switch feature {
 		case PromptMark:
+			if !slices.Contains(supportedShells, sh) {
+				continue
+			}
+
 			result.WriteString(w.iTermPromptMark)
 		case CurrentDir:
 			result.WriteString(fmt.Sprintf(w.iTermCurrentDir, pwd))
